@@ -708,6 +708,15 @@ void add_ide_sysfs_info(hd_data_t *hd_data, hd_t *hd)
 
 /*
  * assumes hd->drivers aleady includes scsi device drivers (like 'sd')
+ *
+ * The following code uses ioctl() calls to issue some SCSI commands
+ * directly (namely the INQUIRY command).
+ *
+ * For reference, and to understand the layout of the ioctl() calls below,
+ * google for a document named 'SCSI Primary Commands 5 (SPC-5)' (or more
+ * recent versions - it doesn't matter for our purpose).
+ *
+ * The latest draft is usually freely available but not directly downloadable.
  */
 void add_scsi_sysfs_info(hd_data_t *hd_data, hd_t *hd, char *sf_dev)
 {
@@ -992,7 +1001,7 @@ void add_scsi_sysfs_info(hd_data_t *hd_data, hd_t *hd, char *sf_dev)
       str_printf(&pr_str, 0, "%s serial", hd->unix_dev_name);
       PROGRESS(5, 2, pr_str);
 
-      char *serial_buf = NULL;
+      unsigned char *serial_buf = NULL;
       unsigned serial_buf_len = 0;
       memset(scsi_cmd_buf, 0, sizeof scsi_cmd_buf);
 
